@@ -55,6 +55,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
+#include <time.h>
 #include <sys/types.h>
 #include <sys/time.h>
 #include <ctype.h>
@@ -265,7 +266,6 @@ int             ii, jj;
 int             firsttime, notdoneyet;
 int             yourchar;
 float           randexp, randnum;
-extern time_t   time ();
 struct sigaction handler;
 
     if (argc == 1 && isatty (fileno (stdin)))
